(harmonic-examples)=

# Harmonic-based morphometrics examples

Examples concerning the :mod:`ktch.harmonic` module.

```{eval-rst}
.. toctree::
    :maxdepth: 1
    :glob:

    ./elliptic_Fourier_analysis
    ./manipulating_coordinate_values
    ./elliptic_Fourier_analysis_3d
    ./spharm
```
